library(testthat)
library(newsmd)

testthat::test_check("newsmd")
